@@ -1,6 +1,32 @@
 // eslint-disable-next-line no-unused-vars
 import { K8sKind } from '../module/k8s';
 
+export const CatalogSourceConfigModel: K8sKind = {
+  kind: 'CatalogSourceConfig',
+  label: 'CatalogSourceConfig',
+  labelPlural: 'CatalogSourceConfigs',
+  apiGroup: 'operators.coreos.com',
+  apiVersion: 'v1',
+  path: 'catalogsourceconfigs',
+  abbr: 'CSC',
+  namespaced: true,
+  crd: true,
+  plural: 'catalogsourceconfigs',
+};
+
+export const OperatorSourceModel: K8sKind = {
+  kind: 'OperatorSource',
+  label: 'OperatorSource',
+  labelPlural: 'OperatorSource',
+  apiGroup: 'operators.coreos.com',
+  apiVersion: 'v1',
+  path: 'operatorsources',
+  abbr: 'OSRC',
+  namespaced: true,
+  crd: true,
+  plural: 'operatorsources',
+};
+
 export const CatalogSourceModel: K8sKind = {
   kind: 'CatalogSource',
   label: 'CatalogSource',
@@ -14,6 +40,19 @@ export const CatalogSourceModel: K8sKind = {
   plural: 'catalogsources',
 };
 
+export const PackageManifestModel: K8sKind = {
+  kind: 'PackageManifest',
+  label: 'PackageManifest',
+  labelPlural: 'PackageManifests',
+  apiGroup: 'packages.operators.coreos.com',
+  apiVersion: 'v1',
+  path: 'packagemanifests',
+  abbr: 'PM',
+  namespaced: true,
+  crd: true,
+  plural: 'packagemanifests',
+};
+
 export const ClusterServiceVersionModel: K8sKind = {
   kind: 'ClusterServiceVersion',
   label: 'ClusterServiceVersion',
@@ -54,18 +93,17 @@ export const SubscriptionModel: K8sKind = {
   plural: 'subscriptions',
 };
 
-export const EtcdClusterModel: K8sKind = {
-  kind: 'EtcdCluster',
-  label: 'etcd Cluster',
-  labelPlural: 'Etcd Clusters',
-  apiGroup: 'etcd.database.coreos.com',
-  apiVersion: 'v1beta2',
-  path: 'etcdclusters',
-  abbr: 'EC',
+export const OperatorGroupModel: K8sKind = {
+  kind: 'OperatorGroup',
+  label: 'OperatorGroup',
+  labelPlural: 'OperatorGroups',
+  apiGroup: 'operators.coreos.com',
+  apiVersion: 'v1',
+  path: 'operatorgroups',
+  abbr: 'OG',
   namespaced: true,
   crd: true,
-  plural: 'etcdclusters',
-  propagationPolicy : 'Foreground',
+  plural: 'operatorgroups',
 };
 
 export const PrometheusModel: K8sKind = {
@@ -110,19 +148,6 @@ export const AlertmanagerModel: K8sKind = {
   propagationPolicy : 'Foreground',
 };
 
-export const ClusterModel: K8sKind = {
-  kind: 'Cluster',
-  label: 'Cluster',
-  labelPlural: 'Clusters',
-  apiGroup: 'multicluster.coreos.com',
-  path: 'clusters',
-  apiVersion: 'v1',
-  crd: true,
-  plural: 'clusters',
-  abbr: 'C',
-  namespaced: false,
-};
-
 export const ChargebackReportModel: K8sKind = {
   kind: 'Report',
   label: 'Report',
@@ -145,7 +170,7 @@ export const ServiceModel: K8sKind = {
   namespaced: true,
   kind: 'Service',
   id: 'service',
-  labelPlural: 'Services'
+  labelPlural: 'Services',
 };
 
 export const PodModel: K8sKind = {
@@ -157,7 +182,7 @@ export const PodModel: K8sKind = {
   namespaced: true,
   kind: 'Pod',
   id: 'pod',
-  labelPlural: 'Pods'
+  labelPlural: 'Pods',
 };
 
 export const ContainerModel: K8sKind = {
@@ -168,7 +193,7 @@ export const ContainerModel: K8sKind = {
   abbr: 'C',
   kind: 'Container',
   id: 'container',
-  labelPlural: 'Containers'
+  labelPlural: 'Containers',
 };
 
 export const DaemonSetModel: K8sKind = {
@@ -182,7 +207,7 @@ export const DaemonSetModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'DaemonSet',
   id: 'daemonset',
-  labelPlural: 'Daemon Sets'
+  labelPlural: 'Daemon Sets',
 };
 
 export const ReplicationControllerModel: K8sKind = {
@@ -195,7 +220,7 @@ export const ReplicationControllerModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'ReplicationController',
   id: 'replicationcontroller',
-  labelPlural: 'Replication Controllers'
+  labelPlural: 'Replication Controllers',
 };
 
 export const HorizontalPodAutoscalerModel: K8sKind = {
@@ -208,7 +233,7 @@ export const HorizontalPodAutoscalerModel: K8sKind = {
   namespaced: true,
   kind: 'HorizontalPodAutoscaler',
   id: 'horizontalpodautoscaler',
-  labelPlural: 'Horizontal Pod Autoscalers'
+  labelPlural: 'Horizontal Pod Autoscalers',
 };
 
 export const ServiceAccountModel: K8sKind = {
@@ -220,7 +245,7 @@ export const ServiceAccountModel: K8sKind = {
   namespaced: true,
   kind: 'ServiceAccount',
   id: 'serviceaccount',
-  labelPlural: 'Service Accounts'
+  labelPlural: 'Service Accounts',
 };
 
 export const ReplicaSetModel: K8sKind = {
@@ -234,7 +259,7 @@ export const ReplicaSetModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'ReplicaSet',
   id: 'replicaset',
-  labelPlural: 'Replica Sets'
+  labelPlural: 'Replica Sets',
 };
 
 export const DeploymentModel: K8sKind = {
@@ -248,7 +273,7 @@ export const DeploymentModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'Deployment',
   id: 'deployment',
-  labelPlural: 'Deployments'
+  labelPlural: 'Deployments',
 };
 
 export const DeploymentConfigModel: K8sKind = {
@@ -262,7 +287,7 @@ export const DeploymentConfigModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'DeploymentConfig',
   id: 'deploymentconfig',
-  labelPlural: 'Deployment Configs'
+  labelPlural: 'Deployment Configs',
 };
 
 export const BuildConfigModel: K8sKind = {
@@ -276,7 +301,7 @@ export const BuildConfigModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'BuildConfig',
   id: 'buildconfig',
-  labelPlural: 'Build Configs'
+  labelPlural: 'Build Configs',
 };
 
 export const BuildModel: K8sKind = {
@@ -290,7 +315,7 @@ export const BuildModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'Build',
   id: 'build',
-  labelPlural: 'Builds'
+  labelPlural: 'Builds',
 };
 
 export const ImageStreamModel: K8sKind = {
@@ -304,7 +329,7 @@ export const ImageStreamModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'ImageStream',
   id: 'imagestream',
-  labelPlural: 'Image Streams'
+  labelPlural: 'Image Streams',
 };
 
 export const ImageStreamTagModel: K8sKind = {
@@ -318,7 +343,20 @@ export const ImageStreamTagModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'ImageStreamTag',
   id: 'imagestreamtag',
-  labelPlural: 'Image Stream Tags'
+  labelPlural: 'Image Stream Tags',
+};
+
+export const ImageStreamImportsModel: K8sKind = {
+  label: 'Image Stream Import',
+  apiVersion: 'v1',
+  path: 'imagestreamimports',
+  apiGroup: 'image.openshift.io',
+  plural: 'imagestreamimports',
+  abbr: 'ISI',
+  namespaced: true,
+  kind: 'ImageStreamImport',
+  id: 'imagestreamimport',
+  labelPlural: 'Image Stream Imports',
 };
 
 export const JobModel: K8sKind = {
@@ -332,7 +370,7 @@ export const JobModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'Job',
   id: 'job',
-  labelPlural: 'Jobs'
+  labelPlural: 'Jobs',
 };
 
 export const NodeModel: K8sKind = {
@@ -343,7 +381,7 @@ export const NodeModel: K8sKind = {
   abbr: 'N',
   kind: 'Node',
   id: 'node',
-  labelPlural: 'Nodes'
+  labelPlural: 'Nodes',
 };
 
 export const EventModel: K8sKind = {
@@ -355,7 +393,7 @@ export const EventModel: K8sKind = {
   namespaced: true,
   kind: 'Event',
   id: 'event',
-  labelPlural: 'Events'
+  labelPlural: 'Events',
 };
 
 export const ComponentStatusModel: K8sKind = {
@@ -366,7 +404,7 @@ export const ComponentStatusModel: K8sKind = {
   plural: 'componentstatuses',
   abbr: 'CS',
   kind: 'ComponentStatus',
-  id: 'componentstatus'
+  id: 'componentstatus',
 };
 
 export const NamespaceModel: K8sKind = {
@@ -377,7 +415,7 @@ export const NamespaceModel: K8sKind = {
   abbr: 'NS',
   kind: 'Namespace',
   id: 'namespace',
-  labelPlural: 'Namespaces'
+  labelPlural: 'Namespaces',
 };
 
 export const ProjectModel: K8sKind = {
@@ -389,7 +427,7 @@ export const ProjectModel: K8sKind = {
   abbr: 'PR',
   kind: 'Project',
   id: 'project',
-  labelPlural: 'Projects'
+  labelPlural: 'Projects',
 };
 
 export const ProjectRequestModel: K8sKind = {
@@ -401,7 +439,7 @@ export const ProjectRequestModel: K8sKind = {
   abbr: '',
   kind: 'ProjectRequest',
   id: 'projectrequest',
-  labelPlural: 'Project Requests'
+  labelPlural: 'Project Requests',
 };
 
 export const IngressModel: K8sKind = {
@@ -414,7 +452,7 @@ export const IngressModel: K8sKind = {
   abbr: 'I',
   namespaced: true,
   kind: 'Ingress',
-  id: 'ingress'
+  id: 'ingress',
 };
 
 export const RouteModel: K8sKind = {
@@ -427,7 +465,7 @@ export const RouteModel: K8sKind = {
   abbr: 'RT',
   namespaced: true,
   kind: 'Route',
-  id: 'route'
+  id: 'route',
 };
 
 export const ConfigMapModel: K8sKind = {
@@ -439,7 +477,7 @@ export const ConfigMapModel: K8sKind = {
   namespaced: true,
   kind: 'ConfigMap',
   id: 'configmap',
-  labelPlural: 'Config Maps'
+  labelPlural: 'Config Maps',
 };
 
 export const SecretModel: K8sKind = {
@@ -451,7 +489,7 @@ export const SecretModel: K8sKind = {
   namespaced: true,
   kind: 'Secret',
   id: 'secret',
-  labelPlural: 'Secrets'
+  labelPlural: 'Secrets',
 };
 
 export const ClusterRoleBindingModel: K8sKind = {
@@ -463,7 +501,7 @@ export const ClusterRoleBindingModel: K8sKind = {
   abbr: 'CRB',
   kind: 'ClusterRoleBinding',
   id: 'clusterrolebinding',
-  labelPlural: 'Cluster Role Bindings'
+  labelPlural: 'Cluster Role Bindings',
 };
 
 export const ClusterRoleModel: K8sKind = {
@@ -475,7 +513,7 @@ export const ClusterRoleModel: K8sKind = {
   abbr: 'CR',
   kind: 'ClusterRole',
   id: 'clusterrole',
-  labelPlural: 'Cluster Roles'
+  labelPlural: 'Cluster Roles',
 };
 
 export const RoleBindingModel: K8sKind = {
@@ -488,7 +526,7 @@ export const RoleBindingModel: K8sKind = {
   namespaced: true,
   kind: 'RoleBinding',
   id: 'rolebinding',
-  labelPlural: 'Role Bindings'
+  labelPlural: 'Role Bindings',
 };
 
 export const RoleModel: K8sKind = {
@@ -501,7 +539,7 @@ export const RoleModel: K8sKind = {
   namespaced: true,
   kind: 'Role',
   id: 'role',
-  labelPlural: 'Roles'
+  labelPlural: 'Roles',
 };
 
 export const SelfSubjectAccessReviewModel: K8sKind = {
@@ -514,46 +552,7 @@ export const SelfSubjectAccessReviewModel: K8sKind = {
   namespaced: true,
   kind: 'SelfSubjectAccessReview',
   id: 'selfsubjectaccessreview',
-  labelPlural: 'Self Subject Access Reviews'
-};
-
-export const TectonicVersionModel: K8sKind = {
-  label: 'Tectonic Version',
-  apiGroup: 'tco.coreos.com',
-  apiVersion: 'v1',
-  path: 'tectonicversions',
-  plural: 'tectonicversions',
-  abbr: 'TV',
-  namespaced: true,
-  kind: 'TectonicVersion',
-  id: 'tectonicversion',
-  labelPlural: 'Tectonic Versions'
-};
-
-export const ChannelOperatorConfigModel: K8sKind = {
-  label: 'Channel Operator Config',
-  apiGroup: 'tco.coreos.com',
-  apiVersion: 'v1',
-  path: 'channeloperatorconfigs',
-  plural: 'channeloperatorconfigs',
-  abbr: 'COC',
-  namespaced: true,
-  kind: 'ChannelOperatorConfig',
-  id: 'channeloperatorconfig',
-  labelPlural: 'Channel Operator Configs'
-};
-
-export const AppVersionModel: K8sKind = {
-  label: 'AppVersion',
-  apiGroup: 'tco.coreos.com',
-  apiVersion: 'v1',
-  path: 'appversions',
-  plural: 'appversions',
-  abbr: 'AV',
-  namespaced: true,
-  kind: 'AppVersion',
-  id: 'appversion',
-  labelPlural: 'AppVersions'
+  labelPlural: 'Self Subject Access Reviews',
 };
 
 export const PersistentVolumeModel: K8sKind = {
@@ -564,7 +563,7 @@ export const PersistentVolumeModel: K8sKind = {
   abbr: 'PV',
   kind: 'PersistentVolume',
   id: 'persistentvolume',
-  labelPlural: 'Persistent Volumes'
+  labelPlural: 'Persistent Volumes',
 };
 
 export const PersistentVolumeClaimModel: K8sKind = {
@@ -576,7 +575,7 @@ export const PersistentVolumeClaimModel: K8sKind = {
   namespaced: true,
   kind: 'PersistentVolumeClaim',
   id: 'persistentvolumeclaim',
-  labelPlural: 'Persistent Volume Claims'
+  labelPlural: 'Persistent Volume Claims',
 };
 
 export const PetsetModel: K8sKind = {
@@ -588,7 +587,7 @@ export const PetsetModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'Petset',
   id: 'petset',
-  labelPlural: 'Petsets'
+  labelPlural: 'Petsets',
 };
 
 export const StatefulSetModel: K8sKind = {
@@ -602,7 +601,7 @@ export const StatefulSetModel: K8sKind = {
   propagationPolicy: 'Foreground',
   kind: 'StatefulSet',
   id: 'statefulset',
-  labelPlural: 'Stateful Sets'
+  labelPlural: 'Stateful Sets',
 };
 
 export const ResourceQuotaModel: K8sKind = {
@@ -614,7 +613,20 @@ export const ResourceQuotaModel: K8sKind = {
   namespaced: true,
   kind: 'ResourceQuota',
   id: 'resourcequota',
-  labelPlural: 'Resource Quotas'
+  labelPlural: 'Resource Quotas',
+};
+
+export const ClusterResourceQuotaModel: K8sKind = {
+  label: 'Cluster Resource Quota',
+  apiGroup: 'quota.openshift.io',
+  apiVersion: 'v1',
+  path: 'clusterresourcequotas',
+  plural: 'clusterresourcequotas',
+  abbr: 'CRQ',
+  namespaced: false,
+  kind: 'ClusterResourceQuota',
+  id: 'clusterresourcequota',
+  labelPlural: 'Cluster Resource Quotas',
 };
 
 export const NetworkPolicyModel: K8sKind = {
@@ -627,7 +639,7 @@ export const NetworkPolicyModel: K8sKind = {
   abbr: 'NP',
   namespaced: true,
   kind: 'NetworkPolicy',
-  id: 'networkpolicy'
+  id: 'networkpolicy',
 };
 
 export const CustomResourceDefinitionModel: K8sKind = {
@@ -640,7 +652,7 @@ export const CustomResourceDefinitionModel: K8sKind = {
   plural: 'customresourcedefinitions',
   kind: 'CustomResourceDefinition',
   id: 'customresourcedefinition',
-  labelPlural: 'Custom Resource Definitions'
+  labelPlural: 'Custom Resource Definitions',
 };
 
 export const CronJobModel: K8sKind = {
@@ -667,7 +679,7 @@ export const StorageClassModel: K8sKind = {
   abbr: 'SC',
   namespaced: false,
   kind: 'StorageClass',
-  id: 'storageclass'
+  id: 'storageclass',
 };
 
 export const ClusterServiceBrokerModel: K8sKind = {
@@ -680,7 +692,8 @@ export const ClusterServiceBrokerModel: K8sKind = {
   abbr: 'CSB',
   namespaced: false,
   kind: 'ClusterServiceBroker',
-  id: 'clusterservicebroker'
+  id: 'clusterservicebroker',
+  crd: true,
 };
 
 export const ClusterServiceClassModel: K8sKind = {
@@ -693,7 +706,8 @@ export const ClusterServiceClassModel: K8sKind = {
   abbr: 'CSC',
   namespaced: false,
   kind: 'ClusterServiceClass',
-  id: 'clusterserviceclass'
+  id: 'clusterserviceclass',
+  crd: true,
 };
 
 export const ClusterServicePlanModel: K8sKind = {
@@ -706,7 +720,8 @@ export const ClusterServicePlanModel: K8sKind = {
   abbr: 'CSP',
   namespaced: false,
   kind: 'ClusterServicePlan',
-  id: 'clusterserviceplan'
+  id: 'clusterserviceplan',
+  crd: true,
 };
 
 export const ServiceInstanceModel: K8sKind = {
@@ -719,7 +734,8 @@ export const ServiceInstanceModel: K8sKind = {
   abbr: 'SI',
   namespaced: true,
   kind: 'ServiceInstance',
-  id: 'serviceinstance'
+  id: 'serviceinstance',
+  crd: true,
 };
 
 export const ServiceBindingModel: K8sKind = {
@@ -732,5 +748,162 @@ export const ServiceBindingModel: K8sKind = {
   abbr: 'SB',
   namespaced: true,
   kind: 'ServiceBinding',
-  id: 'servicebinding'
+  id: 'servicebinding',
+  crd: true,
+};
+
+export const LimitRangeModel: K8sKind = {
+  label: 'Limit Range',
+  apiVersion: 'v1',
+  path: 'limitranges',
+  plural: 'limitranges',
+  abbr: 'LR',
+  namespaced: true,
+  kind: 'LimitRange',
+  id: 'limitrange',
+  labelPlural: 'Limit Ranges',
+};
+
+export const APIServiceModel: K8sKind = {
+  label: 'API Service',
+  labelPlural: 'API Services',
+  apiVersion: 'v1',
+  path: 'apiservices',
+  apiGroup: 'apiregistration.k8s.io',
+  plural: 'apiservices',
+  abbr: 'APIS',
+  namespaced: false,
+  kind: 'APIService',
+  id: 'apiservice',
+  crd: true,
+};
+
+// Cluster API resources
+// https://github.com/openshift/cluster-api
+export const MachineModel: K8sKind = {
+  label: 'Machine',
+  labelPlural: 'Machines',
+  apiVersion: 'v1beta1',
+  path: 'machines',
+  apiGroup: 'machine.openshift.io',
+  plural: 'machines',
+  abbr: 'M',
+  namespaced: true,
+  kind: 'Machine',
+  id: 'machine',
+  crd: true,
+};
+
+export const MachineSetModel: K8sKind = {
+  label: 'Machine Set',
+  labelPlural: 'Machine Sets',
+  apiVersion: 'v1beta1',
+  path: 'machinesets',
+  apiGroup: 'machine.openshift.io',
+  plural: 'machinesets',
+  abbr: 'MS',
+  namespaced: true,
+  kind: 'MachineSet',
+  id: 'machineset',
+  crd: true,
+};
+
+export const MachineDeploymentModel: K8sKind = {
+  label: 'Machine Deployment',
+  labelPlural: 'Machine Deployments',
+  apiVersion: 'v1beta1',
+  path: 'machinedeployments',
+  apiGroup: 'machine.openshift.io',
+  plural: 'machinedeployments',
+  abbr: 'MD',
+  namespaced: true,
+  kind: 'MachineDeployment',
+  id: 'machinedeployment',
+  crd: true,
+};
+
+export const MachineConfigPoolModel: K8sKind = {
+  label: 'Machine Config Pool',
+  labelPlural: 'Machine Config Pools',
+  apiVersion: 'v1',
+  path: 'machineconfigpools',
+  apiGroup: 'machineconfiguration.openshift.io',
+  plural: 'machineconfigpools',
+  abbr: 'MCP',
+  namespaced: false,
+  kind: 'MachineConfigPool',
+  id: 'machineconfigpool',
+  crd: true,
+};
+
+export const MachineConfigModel: K8sKind = {
+  label: 'Machine Config',
+  labelPlural: 'Machine Configs',
+  apiVersion: 'v1',
+  path: 'machineconfigs',
+  apiGroup: 'machineconfiguration.openshift.io',
+  plural: 'machineconfigs',
+  abbr: 'MC',
+  namespaced: false,
+  kind: 'MachineConfig',
+  id: 'machineconfigpool',
+  crd: true,
+};
+
+// Openshift cluster resources
+export const ClusterOperatorModel: K8sKind = {
+  label: 'Cluster Operator',
+  labelPlural: 'Cluster Operators',
+  apiVersion: 'v1',
+  path: 'clusteroperators',
+  apiGroup: 'config.openshift.io',
+  plural: 'clusteroperators',
+  abbr: 'CO',
+  namespaced: false,
+  kind: 'ClusterOperator',
+  id: 'clusteroperator',
+  crd: true,
+};
+
+export const ClusterVersionModel: K8sKind = {
+  label: 'Cluster Version',
+  labelPlural: 'Cluster Versions',
+  apiVersion: 'v1',
+  path: 'clusterversions',
+  apiGroup: 'config.openshift.io',
+  plural: 'clusterversions',
+  abbr: 'CV',
+  namespaced: false,
+  kind: 'ClusterVersion',
+  id: 'clusterversion',
+  crd: true,
+};
+
+export const ClusterAutoscalerModel: K8sKind = {
+  label: 'Cluster Autoscaler',
+  labelPlural: 'Cluster Autoscalers',
+  apiVersion: 'v1',
+  path: 'clusterautoscalers',
+  apiGroup: 'autoscaling.openshift.io',
+  plural: 'clusterautoscalers',
+  abbr: 'CA',
+  namespaced: false,
+  kind: 'ClusterAutoscaler',
+  id: 'clusterautoscaler',
+  crd: true,
+};
+
+// OpenShift global configuration
+export const OAuthModel: K8sKind = {
+  label: 'OAuth',
+  labelPlural: 'OAuths',
+  apiVersion: 'v1',
+  path: 'oauths',
+  apiGroup: 'config.openshift.io',
+  plural: 'oauths',
+  abbr: 'OA',
+  namespaced: false,
+  kind: 'OAuth',
+  id: 'oauth',
+  crd: true,
 };
